Package: harbinger
Title: A Unified Time Series Event Detection Framework
Version: 2.0.757
Author: Eduardo Ogasawara [aut, ths, cre] (ORCID:
    <https://orcid.org/0000-0002-0466-0626>),
  Anthony Heimlich [aut],
  Antonio Castro [aut],
  Antonio Mello [aut],
  Diego Carvalho [ctb],
  Eduardo Bezerra [ctb],
  Ellen Paixão [aut],
  Fernando Fraga [aut],
  Gabriel Giuliano [aut],
  Heraldo Borges [aut],
  Igor Andrade [aut],
  Isabele Rocha [aut],
  Janio Lima [aut],
  Jessica Souza [aut],
  Lais Baroni [aut],
  Lucas Tavares [aut],
  Michel Reis [aut],
  Rebecca Salles [aut],
  CEFET/RJ [cph]
Maintainer: Eduardo Ogasawara <eogasawara@ieee.org>
Authors@R: 
  c(    person(given = "Eduardo", family = "Ogasawara", role = c("aut", "ths", "cre"), 
               email = "eogasawara@ieee.org", comment = c(ORCID = "0000-0002-0466-0626")),
        person(given = "Anthony", family = "Heimlich", role = c("aut"), email = "anthony.heimlich@eic.cefet-rj.br"),
        person(given = "Antonio", family = "Castro", role = c("aut"), email = "antonio.castro@eic.cefet-rj.br"),
        person(given = "Antonio", family = "Mello", role = c("aut"), email = "antonio.mello@eic.cefet-rj.br"),
        person(given = "Diego", family = "Carvalho", role = c("ctb"), email = "d.carvalho@ieee.org"),
        person(given = "Eduardo", family = "Bezerra", role = c("ctb"), email = "ebezerra@cefet-rj.br"),
        person(given = "Ellen", family = "Paixão", role = c("aut"), email = "ellen.paixao@eic.cefet-rj.br"),
        person(given = "Fernando", family = "Fraga", role = c("aut"), email = "fernando.fraga@eic.cefet-rj.br"),
        person(given = "Gabriel", family = "Giuliano", role = c("aut"), email = "gabriel.giuliano@eic.cefet-rj.br"),
        person(given = "Heraldo", family = "Borges", role = c("aut"), email = "heraldo.borges@cefet-rj.br"),
        person(given = "Igor", family = "Andrade", role = c("aut"), email = "igor.andrade@eic.cefet-rj.br"),
        person(given = "Isabele", family = "Rocha", role = c("aut"), email = "isabele.rocha@eic.cefet-rj.br"),
        person(given = "Janio", family = "Lima", role = c("aut"), email = "janio.lima@eic.cefet-rj.br"),
        person(given = "Jessica", family = "Souza", role = c("aut"), email = "jessica.souza@eic.cefet-rj.br"),
        person(given = "Lais", family = "Baroni", role = c("aut"), email = "lais.baronis@eic.cefet-rj.br"),
        person(given = "Lucas", family = "Tavares", role = c("aut"), email = "lucas.tavares@eic.cefet-rj.br"),
        person(given = "Michel", family = "Reis", role = c("aut"), email = "michel.reis@eic.cefet-rj.br"),
        person(given = "Rebecca", family = "Salles", role = c("aut"), email = "rebecca.salles@eic.cefet-rj.br"),
        person(given = "CEFET/RJ", role = "cph")
   )
Description: By analyzing time series, it is possible to observe significant changes in the behavior of observations that frequently characterize events. Events present themselves as anomalies, change points, or motifs. In the literature, there are several methods for detecting events. However, searching for a suitable time series method is a complex task, especially considering that the nature of events is often unknown. This work presents Harbinger, a framework for integrating and analyzing event detection methods. Harbinger contains several state-of-the-art methods described in Salles et al. (2020) <doi:10.5753/sbbd.2020.13626>.
License: MIT + file LICENSE
URL: https://cefet-rj-dal.github.io/harbinger/,
        https://github.com/cefet-rj-dal/harbinger
BugReports: https://github.com/cefet-rj-dal/harbinger/issues
Encoding: UTF-8
Depends: R (>= 4.1.0)
RoxygenNote: 8.0.0
Imports: tspredit, changepoint, daltoolbox, forecast, ggplot2, hht,
        RcppHungarian, dplyr, dtwclust, rugarch, patchwork, stats,
        stringr, strucchange, tsmp, wavelets, zoo
Suggests: ocp
NeedsCompilation: no
Packaged: 2026-05-22 11:56:36 UTC; gpca
Repository: CRAN
Date/Publication: 2026-05-22 12:40:02 UTC
Built: R 4.5.2; ; 2026-05-25 02:46:01 UTC; unix
