# Generated by roxygen2: do not edit by hand

S3method(detect,han_autoencoder)
S3method(detect,hanc_ml)
S3method(detect,hanct_dtw)
S3method(detect,hanct_kmeans)
S3method(detect,hanr_arima)
S3method(detect,hanr_emd)
S3method(detect,hanr_fbiad)
S3method(detect,hanr_fft)
S3method(detect,hanr_fft_amoc)
S3method(detect,hanr_fft_amoc_cusum)
S3method(detect,hanr_fft_binseg)
S3method(detect,hanr_fft_binseg_cusum)
S3method(detect,hanr_fft_sma)
S3method(detect,hanr_garch)
S3method(detect,hanr_histogram)
S3method(detect,hanr_ml)
S3method(detect,hanr_remd)
S3method(detect,hanr_rtad)
S3method(detect,hanr_wavelet)
S3method(detect,har_ensemble)
S3method(detect,har_ensemble_fuzzy)
S3method(detect,harbinger)
S3method(detect,hcp_amoc)
S3method(detect,hcp_binseg)
S3method(detect,hcp_bocpd)
S3method(detect,hcp_cf_arima)
S3method(detect,hcp_cf_ets)
S3method(detect,hcp_cf_lr)
S3method(detect,hcp_chow)
S3method(detect,hcp_garch)
S3method(detect,hcp_gft)
S3method(detect,hcp_joinpoint)
S3method(detect,hcp_kswin)
S3method(detect,hcp_page_hinkley)
S3method(detect,hcp_pelt)
S3method(detect,hcp_scp)
S3method(detect,hcp_waypoint)
S3method(detect,hdis_mp)
S3method(detect,hdis_sax)
S3method(detect,hmo_mp)
S3method(detect,hmo_sax)
S3method(detect,hmo_xsax)
S3method(detect,hmu_pca)
S3method(evaluate,har_eval)
S3method(evaluate,har_eval_soft)
S3method(evaluate,har_stream_eval)
S3method(evaluate,harbinger)
S3method(fit,han_autoencoder)
S3method(fit,hanc_ml)
S3method(fit,hanct_dtw)
S3method(fit,hanct_kmeans)
S3method(fit,hanr_arima)
S3method(fit,hanr_ml)
S3method(fit,har_ensemble)
S3method(fit,har_ensemble_fuzzy)
S3method(fit,har_online_session)
S3method(fit,hcp_bocpd)
S3method(fit,hcp_cf_arima)
S3method(fit,hcp_joinpoint)
S3method(fit,hcp_kswin)
S3method(fit,hcp_page_hinkley)
S3method(fit,hcp_waypoint)
S3method(next_observation,default)
S3method(next_observation,har_source_callback)
S3method(next_observation,har_source_kafka)
S3method(next_observation,har_source_simulated)
S3method(source_info,default)
S3method(source_info,har_source_callback)
S3method(source_info,har_source_dataframe)
S3method(source_info,har_source_kafka)
S3method(source_info,har_source_simulated)
S3method(transform,trans_sax)
S3method(transform,trans_xsax)
export(collect_batch_log)
export(collect_detection)
export(collect_trace)
export(detect)
export(han_autoencoder)
export(hanc_ml)
export(hanct_dtw)
export(hanct_kmeans)
export(hanr_arima)
export(hanr_emd)
export(hanr_fbiad)
export(hanr_fft)
export(hanr_fft_amoc)
export(hanr_fft_amoc_cusum)
export(hanr_fft_binseg)
export(hanr_fft_binseg_cusum)
export(hanr_fft_sma)
export(hanr_garch)
export(hanr_histogram)
export(hanr_ml)
export(hanr_remd)
export(hanr_rtad)
export(hanr_wavelet)
export(har_ensemble)
export(har_ensemble_fuzzy)
export(har_ensemble_plot)
export(har_ensemble_plot_models)
export(har_eval)
export(har_eval_soft)
export(har_memory_full)
export(har_memory_last_observations)
export(har_memory_sliding)
export(har_online_detect_only)
export(har_online_incremental)
export(har_online_refit_full)
export(har_online_session)
export(har_plot)
export(har_source_callback)
export(har_source_dataframe)
export(har_source_kafka)
export(har_source_simulated)
export(har_stream_eval)
export(har_stream_experiment)
export(harbinger)
export(harutils)
export(hcp_amoc)
export(hcp_binseg)
export(hcp_bocpd)
export(hcp_cf_arima)
export(hcp_cf_ets)
export(hcp_cf_lr)
export(hcp_chow)
export(hcp_garch)
export(hcp_gft)
export(hcp_joinpoint)
export(hcp_kswin)
export(hcp_page_hinkley)
export(hcp_pelt)
export(hcp_scp)
export(hcp_waypoint)
export(hdis_mp)
export(hdis_sax)
export(hmo_mp)
export(hmo_sax)
export(hmo_xsax)
export(hmu_pca)
export(ingest)
export(is_finished)
export(loadfulldata)
export(mas)
export(next_observation)
export(run_online)
export(source_info)
export(step_online)
export(trans_sax)
export(trans_xsax)
import(ggplot2)
import(patchwork)
importFrom(RcppHungarian,HungarianSolver)
importFrom(changepoint,cpt.mean)
importFrom(changepoint,cpt.meanvar)
importFrom(changepoint,cpts)
importFrom(daltoolbox,adjust_data.frame)
importFrom(daltoolbox,autoenc_base_ed)
importFrom(daltoolbox,dal_base)
importFrom(daltoolbox,dal_transform)
importFrom(daltoolbox,evaluate)
importFrom(daltoolbox,fit)
importFrom(daltoolbox,fit_curvature_max)
importFrom(daltoolbox,fit_curvature_min)
importFrom(daltoolbox,transform)
importFrom(dplyr,arrange)
importFrom(dplyr,desc)
importFrom(dplyr,group_by)
importFrom(dplyr,n)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dtwclust,tsclust)
importFrom(forecast,auto.arima)
importFrom(forecast,ets)
importFrom(graphics,hist)
importFrom(hht,CEEMD)
importFrom(rugarch,ugarchfit)
importFrom(rugarch,ugarchspec)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,ecdf)
importFrom(stats,fft)
importFrom(stats,kmeans)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,princomp)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,spec.pgram)
importFrom(stats,ts)
importFrom(stringr,str_length)
importFrom(stringr,str_pad)
importFrom(strucchange,Fstats)
importFrom(strucchange,breakpoints)
importFrom(tsmp,find_motif)
importFrom(tsmp,tsmp)
importFrom(tspredit,ts_arima)
importFrom(tspredit,ts_data)
importFrom(tspredit,ts_norm_gminmax)
importFrom(tspredit,ts_projection)
importFrom(wavelets,modwt)
importFrom(zoo,rollapply)
