% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hanct_kmeans.R
\name{hanct_kmeans}
\alias{hanct_kmeans}
\title{Anomaly detector using k-means}
\usage{
hanct_kmeans(seq = 1, centers = NA)
}
\arguments{
\item{seq}{sequence size}

\item{centers}{number of centroids}
}
\value{
\code{hanct_kmeans} object
}
\description{
Distance-based anomaly and discord detection using k-means clustering.
The detector clusters the series and flags observations or subsequences that
are far from the nearest centroid.
When \code{seq} equals one, isolated observations are labeled as anomalies.
When \code{seq} is greater than one, subsequences are labeled as discords.
Wraps the \code{kmeans} implementation from the \code{stats} package.
}
\examples{
library(daltoolbox)

# Load anomaly example data
data(examples_anomalies)

# Use a simple example
dataset <- examples_anomalies$simple
head(dataset)

# Configure k-means detector
model <- hanct_kmeans()

# Fit the model
model <- fit(model, dataset$serie)

# Run detection
detection <- detect(model, dataset$serie)

# Show detected events
print(detection[(detection$event),])

}
\references{
\itemize{
\item Ogasawara, E., Salles, R., Porto, F., Pacitti, E. Event Detection in Time Series. 1st ed.
Cham: Springer Nature Switzerland, 2025. doi:10.1007/978-3-031-75941-3
}
}
