% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/har_plot_ensemble.R
\name{har_ensemble_plot_models}
\alias{har_ensemble_plot_models}
\title{Plot individual model detections in a Harbinger fuzzy ensemble}
\usage{
har_ensemble_plot_models(detection, serie, time_idx = NULL)
}
\arguments{
\item{detection}{A detection object returned by \code{detect.har_ensemble_fuzzy}.}

\item{serie}{Numeric vector with the original time series.}

\item{time_idx}{Optional x-axis vector.}
}
\value{
A \code{patchwork} object.
}
\description{
Visualizes the original series and the per-model detections stored in the
\code{model_events} attribute returned by \code{detect.har_ensemble_fuzzy()}.
}
