% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/united_loadfulldata.R
\name{loadfulldata}
\alias{loadfulldata}
\title{Load full dataset from mini data object}
\usage{
loadfulldata(x, envir = parent.frame())
}
\arguments{
\item{x}{Dataset object or its name (string or symbol).}

\item{envir}{Environment to load the full dataset into.}
}
\value{
The full dataset object.
}
\description{
The mini datasets stored in \verb{data/} include an \code{attr(url)} pointing to the
full dataset in \verb{harbinger/}. This helper downloads and loads the full data.
}
\examples{
data(A1Benchmark)
A1Benchmark <- loadfulldata(A1Benchmark)
}
